import { useEffect, useState } from "preact/hooks";
import { DataRow } from "../api/DataRow";
import style from './index.module.scss';
import { Posts } from "../components/Posts";
import { Paginator } from "../components/display/Paginator";

const cachedPages: {
    [ key: number ]: DataRow[]
} = {};

let firstRender = true;

export function Index() {
    const [ data, setData ] = useState(null as null | DataRow[]);
    const [ page, setPage ] = useState(NaN);
    const [ pageBlocked, setPageBlocked ] = useState(false);

    async function goToPage(newPage: number) {
        if (newPage < 0) newPage = 0;
        if (pageBlocked) return;

        let newData = null as DataRow[] | null;
        if (cachedPages[newPage]) {
            newData = cachedPages[newPage];
        } else {
            setData(null);
        }

        setPage(newPage);
        setPageBlocked(true);
        try {
            newData = await DataRow.find({
                page: newPage
            });
        } catch (_) {
            return setPageBlocked(false)
        }

        if (newData === undefined) {
            newData = [] as DataRow[];
        }

        cachedPages[newPage] = newData;
        setPageBlocked(false);
        setData(newData);
    }

    if (firstRender) {
        goToPage(0);
        firstRender = false;
    }    

    return (
        <div className={style.index}>
            <Paginator page={page} onChange={goToPage} className={style.paginator} />
            {
                data
                    ? <Posts rows={data} />
                    : <pre>loading . . .</pre>
            }
        </div>
    )
}